@@ -146,6 +146,7 @@ object_details (GObject *source_object, GAsyncResult *res, gpointer user_data)
 
 	switch (cka_class) {
 	case CKO_CERTIFICATE:
+	case CKO_PUBLIC_KEY:
 		store1 = priv->cert_store;
 		store2 = priv->key_store;
 		break;
@@ -228,7 +229,7 @@ next_object (GObject *obj, GAsyncResult *res, gpointer user_data)
 		                      NULL, object_details, self);
 	}
 
-	gck_list_unref_free (objects);
+	g_list_free_full (objects, g_object_unref);
 }
 
 static void
